@@ -11,6 +11,7 @@ def init():
     global DB_PASS
     global DB_HOST
     global DB_SSL_CA
+    global ADMIN_PASSWORD
 
     SA_CONTAINER_NAME = ""
     SA_CONNECTION_STRING = ""
@@ -21,3 +22,4 @@ def init():
     DB_PASS = ""
     DB_HOST = ""
     DB_SSL_CA = ""
+    ADMIN_PASSWORD = ""
